@@ -21,8 +21,6 @@ _ACTION_MAPPING = {
 class BaseComparator(ABC):
     """Base Comparator class."""
 
-    # pylint: disable=no-self-use
-
     def __init__(
         self,
         default_load_kwargs=None,
@@ -276,7 +274,7 @@ class DefaultComparator(BaseComparator):
 
 
 class DictComparator(BaseComparator):
-    """Comparator for dictionnaries."""
+    """Comparator for dictionaries."""
 
     _ACTION_MAPPING = {
         "add": "Added the value(s) '{value}' in the '{key}' key.",
@@ -319,17 +317,17 @@ class DictComparator(BaseComparator):
         return value
 
     def diff(self, ref, comp, *args, **kwargs):
-        """Compare 2 dictionnaries.
+        """Compare 2 dictionaries.
 
         This function calls :func:`dictdiffer.diff` to compare the dictionaries, read the doc of
         this function for details on args and kwargs.
 
         Keyword Args:
-            tolerance: Relative threshold to consider when comparing two float numbers.
-            absolute_tolerance: Absolute threshold to consider when comparing
+            tolerance (float): Relative threshold to consider when comparing two float numbers.
+            absolute_tolerance (float): Absolute threshold to consider when comparing
                 two float numbers.
-            ignore: Set of keys that should not be checked.
-            path_limit: List of path limit tuples or :class:`dictdiffer.utils.Pathlimit`
+            ignore (set[list]): Set of keys that should not be checked.
+            path_limit (list[str]): List of path limit tuples or :class:`dictdiffer.utils.PathLimit`
                 object to limit the diff recursion depth.
         """
         if len(args) > 5:
